﻿using Newtonsoft.Json;
using System;
using System.IO;
using System.Net.Http;
using System.Text;
using System.Threading.Tasks;

namespace CcnExample {
	public class Program {

		private const string Endpoint = "https://pessoas-hml.e-notariado.org.br/";
		private const string ApiKey = ""; // Chave de API vai aqui
		private const string SubscriptionId = ""; // Id do cartório vai aqui
		private const string FileName = "Teste.xml";
		private const string FilePath = @"C:\Temp\CCN";


		static async Task Main(string[] args) {

			var httpClient = new HttpClient() {
				BaseAddress = new Uri(Endpoint),
			};

			httpClient.DefaultRequestHeaders.Add("x-api-key", ApiKey);
			httpClient.DefaultRequestHeaders.Add("x-subscription", SubscriptionId);

			UploadModel upload;

			#region Upload
			var fileWithPath = Path.Combine(FilePath, FileName);

			using (var fileStream = File.OpenRead(fileWithPath)) {
				using (var content = new MultipartFormDataContent()) {
					content.Add(new StreamContent(fileStream), FileName, FileName);

					if (!string.IsNullOrEmpty(FileName)) {
						content.Add(new StringContent(FileName, Encoding.UTF8), "name");
					}

					content.Add(new StringContent("txt/xml", Encoding.UTF8), "contentType");

					var uploadResponse = await httpClient.PostAsync("api/uploads", content);
					uploadResponse.EnsureSuccessStatusCode();

					var uploadResponseJson = await uploadResponse.Content.ReadAsStringAsync();
					upload = JsonConvert.DeserializeObject<UploadModel>(uploadResponseJson);
					
					Console.WriteLine("############ UPLOAD RESPONSE");
					Console.WriteLine(JsonConvert.SerializeObject(upload));
				}
			}
			#endregion

			#region Import

			var importRequest = new ImportRequest() {
				Type = "CcnPessoaFisica",
				Upload = upload
			};
			var jsonContent = new StringContent(JsonConvert.SerializeObject(importRequest), Encoding.UTF8, "application/json");

			var importResponse = await httpClient.PostAsync("api/imports", jsonContent);
			var importResponseJson = await importResponse.Content.ReadAsStringAsync();

			if (!importResponse.IsSuccessStatusCode) {
				Console.WriteLine("############ IMPORT RESPONSE ERROR");
				Console.WriteLine(JsonConvert.SerializeObject(importResponseJson, Formatting.Indented));
			}

			importResponse.EnsureSuccessStatusCode();

			
			var importModel = JsonConvert.DeserializeObject<ImportModel>(importResponseJson);

			Console.WriteLine("############ IMPORT RESPONSE");
			Console.WriteLine(JsonConvert.SerializeObject(importModel, Formatting.Indented));

			#endregion
		}
	}
}
